==> thx_pwc-0.0.4.tar.gz: thx_pwc-0.0.4/thx/pwc/auth.py <==
# coding: utf-8

import logging

from django.conf import settings
from django.contrib.auth import get_user_model
from django.contrib.auth.hashers import make_password
from django.utils.translation import ugettext as _

from mozilla_django_oidc.auth import OIDCAuthenticationBackend
from mozilla_django_oidc.contrib.drf import OIDCAuthentication

from rest_framework import authentication, exceptions
from rest_framework.exceptions import ValidationError
from rest_framework_simplejwt.exceptions import AuthenticationFailed

logger = logging.getLogger('mozilla_django_oidc')
User = get_user_model()


class PwcTokenAuthentication(OIDCAuthentication):

    """
        Attenzione usiamo gli stessi setting del Simple JWT
    """
    # AUTH_HEADER_TYPE_BYTES = set(
    #     h.encode(HTTP_HEADER_ENCODING)
    #     for h in ['GSSO']
    # )
    sso_client = None

    def get_raw_token(self, header):
        """
        Extracts an unvalidated JSON web token from the given "Authorization"
        header value.
        """
        parts = header.split()

        if len(parts) == 0:
            # Empty AUTHORIZATION header sent
            return None

        # if parts[0] not in self.AUTH_HEADER_TYPE_BYTES:
        #     # Assume the header does not contain a JSON web token
        #     return None

        if len(parts) != 2:
            raise AuthenticationFailed(
                _('Authorization header must contain two space-delimited values'),
                code='bad_authorization_header',
            )

        return parts[1]

    def authenticate(self, request):
        logger.info('authenticate')
        if not getattr(settings, 'PWC_SSO_SERVER', False):
            logger.info('PWC_SSO_SERVER False')
            return None
        try:
            return super().authenticate(request)
        except Exception as e:
            logger.error('error on authenticate %s', e)
            return None


class PWCOIDCAuthenticationBackend(OIDCAuthenticationBackend):

    def filter_users_by_claims(self, claims):
        """Return all users matching the specified email."""
        email = claims.get('email')
        logger.debug(f'email ---------> {email}')
        cloud_email = claims.get('cloudEmail')
        logger.debug(f'cloudEmail ---------> {cloud_email}')
        if not email:
            if not cloud_email:
                return self.UserModel.objects.none()
            else:
                return self.UserModel.objects.filter(email__iexact=cloud_email)
        else:
            users = self.UserModel.objects.filter(email__iexact=email)
            logger.debug(f'users email ---------> {users}')
            if not users:
                if cloud_email:
                    users = self.UserModel.objects.filter(email__iexact=cloud_email)
            logger.debug(f'users cloudemail ---------> {users}')
            return users


class TraefikForwardAuthentication(authentication.BaseAuthentication):
    def authenticate(self, request):
        if not settings.THX_PWC_TRAEFIK_FORWARD_AUTH:
            return None
        
        cookies = request.COOKIES
        _forward_auth = cookies.get('_forward_auth')

        if not _forward_auth:
            return None
        try:
            user = User.objects.get(email=_forward_auth.split('|')[2])
        except User.DoesNotExist:
            raise exceptions.AuthenticationFailed('PWCNOAUTH')

        return user, None

==> thx_pwc-0.0.5.tar.gz: thx_pwc-0.0.5/thx/pwc/auth.py <==
# coding: utf-8

import logging

from django.conf import settings
from django.contrib.auth import get_user_model
from django.contrib.auth.hashers import make_password
from django.utils.translation import ugettext as _

from mozilla_django_oidc.auth import OIDCAuthenticationBackend
from mozilla_django_oidc.contrib.drf import OIDCAuthentication

from rest_framework import authentication, exceptions
from rest_framework.exceptions import ValidationError
from rest_framework_simplejwt.exceptions import AuthenticationFailed

logger = logging.getLogger('mozilla_django_oidc')
User = get_user_model()


class PwcTokenAuthentication(OIDCAuthentication):

    """
        Attenzione usiamo gli stessi setting del Simple JWT
    """
    # AUTH_HEADER_TYPE_BYTES = set(
    #     h.encode(HTTP_HEADER_ENCODING)
    #     for h in ['GSSO']
    # )
    sso_client = None

    def get_raw_token(self, header):
        """
        Extracts an unvalidated JSON web token from the given "Authorization"
        header value.
        """
        parts = header.split()

        if len(parts) == 0:
            # Empty AUTHORIZATION header sent
            return None

        # if parts[0] not in self.AUTH_HEADER_TYPE_BYTES:
        #     # Assume the header does not contain a JSON web token
        #     return None

        if len(parts) != 2:
            raise AuthenticationFailed(
                _('Authorization header must contain two space-delimited values'),
                code='bad_authorization_header',
            )

        return parts[1]

    def authenticate(self, request):
        logger.info('authenticate')
        if not getattr(settings, 'PWC_SSO_SERVER', False):
            logger.info('PWC_SSO_SERVER False')
            return None
        try:
            return super().authenticate(request)
        except Exception as e:
            logger.error('error on authenticate %s', e)
            return None


class PWCOIDCAuthenticationBackend(OIDCAuthenticationBackend):

    def filter_users_by_claims(self, claims):
        """Return all users matching the specified email."""
        email = claims.get('email')
        logger.debug(f'email ---------> {email}')
        cloud_email = claims.get('cloudEmail')
        logger.debug(f'cloudEmail ---------> {cloud_email}')
        if not email:
            if not cloud_email:
                return self.UserModel.objects.none()
            else:
                return self.UserModel.objects.filter(email__iexact=cloud_email)
        else:
            users = self.UserModel.objects.filter(email__iexact=email)
            logger.debug(f'users email ---------> {users}')
            if not users:
                if cloud_email:
                    users = self.UserModel.objects.filter(email__iexact=cloud_email)
            logger.debug(f'users cloudemail ---------> {users}')
            return users


class TraefikForwardAuthentication(authentication.BaseAuthentication):
    def authenticate(self, request):
        if not settings.THX_PWC_TRAEFIK_FORWARD_AUTH:
            return None
        
        cookies = request.COOKIES
        _forward_auth = cookies.get('_forward_auth')

        if not _forward_auth:
            return None
        try:
            user = User.objects.get(is_active=True, email=_forward_auth.split('|')[2])
        except User.DoesNotExist:
            raise exceptions.AuthenticationFailed('PWCNOAUTH')

        return user, None
